@@ -1,7 +1,7 @@
 /* amitk_color_table.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -382,6 +382,17 @@ rgba_t amitk_color_table_lookup(amide_data_t datum, AmitkColorTable which,
   return rgba;
 }
 
+rgba_t amitk_color_table_uint32_to_rgba(guint32 color_uint32) {
+  rgba_t rgba;
+
+  rgba.r = (color_uint32 >> 24) & 0x000000FF;
+  rgba.g = (color_uint32 >> 16) & 0x000000FF;
+  rgba.b = (color_uint32 >> 8) & 0x000000FF;
+  rgba.a = (color_uint32 >> 0) & 0x000000FF;
+
+  return rgba;
+}
+
 
 rgba_t amitk_color_table_outline_color(AmitkColorTable which, gboolean highlight) {
 
