@@ -1,7 +1,7 @@
 /* amitk_data_set.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -63,6 +63,7 @@ G_BEGIN_DECLS
 #define AMITK_DATA_SET_COLOR_TABLE(ds, view_mode)  (AMITK_DATA_SET(ds)->color_table[view_mode])
 #define AMITK_DATA_SET_COLOR_TABLE_INDEPENDENT(ds, view_mode) (AMITK_DATA_SET(ds)->color_table_independent[view_mode])
 #define AMITK_DATA_SET_INTERPOLATION(ds)           (AMITK_DATA_SET(ds)->interpolation)
+#define AMITK_DATA_SET_RENDERING(ds)               (AMITK_DATA_SET(ds)->rendering)
 #define AMITK_DATA_SET_DYNAMIC(ds)                 (AMITK_DATA_SET_NUM_FRAMES(ds) > 1)
 #define AMITK_DATA_SET_GATED(ds)                   (AMITK_DATA_SET_NUM_GATES(ds) > 1)
 #define AMITK_DATA_SET_THRESHOLDING(ds)            (AMITK_DATA_SET(ds)->thresholding)
@@ -72,6 +73,7 @@ G_BEGIN_DECLS
 #define AMITK_DATA_SET_SUBJECT_NAME(ds)            (AMITK_DATA_SET(ds)->subject_name)
 #define AMITK_DATA_SET_SUBJECT_ID(ds)              (AMITK_DATA_SET(ds)->subject_id)
 #define AMITK_DATA_SET_SUBJECT_DOB(ds)             (AMITK_DATA_SET(ds)->subject_dob)
+#define AMITK_DATA_SET_SERIES_NUMBER(ds)           (AMITK_DATA_SET(ds)->series_number)
 #define AMITK_DATA_SET_DICOM_IMAGE_TYPE(ds)        (AMITK_DATA_SET(ds)->dicom_image_type)
 #define AMITK_DATA_SET_SCAN_START(ds)              (AMITK_DATA_SET(ds)->scan_start)
 #define AMITK_DATA_SET_THRESHOLD_REF_FRAME(ds,ref_frame) (AMITK_DATA_SET(ds)->threshold_ref_frame[ref_frame])
@@ -92,6 +94,8 @@ G_BEGIN_DECLS
 #define AMITK_DATA_SET_DISPLAYED_CYLINDER_UNIT(ds) (AMITK_DATA_SET(ds)->displayed_cylinder_unit)
 #define AMITK_DATA_SET_INVERSION_TIME(ds)          (AMITK_DATA_SET(ds)->inversion_time)
 #define AMITK_DATA_SET_ECHO_TIME(ds)               (AMITK_DATA_SET(ds)->echo_time)
+#define AMITK_DATA_SET_DIFFUSION_B_VALUE(ds)       (AMITK_DATA_SET(ds)->diffusion_b_value)
+#define AMITK_DATA_SET_DIFFUSION_DIRECTION(ds)     (AMITK_DATA_SET(ds)->diffusion_direction)
 #define AMITK_DATA_SET_THRESHOLD_WINDOW(ds, i_win, limit) (AMITK_DATA_SET(ds)->threshold_window[i_win][limit])
 #define AMITK_DATA_SET_VIEW_START_GATE(ds)         (AMITK_DATA_SET(ds)->view_start_gate)
 #define AMITK_DATA_SET_VIEW_END_GATE(ds)           (AMITK_DATA_SET(ds)->view_end_gate)
@@ -100,10 +104,17 @@ G_BEGIN_DECLS
 #define AMITK_DATA_SET_DISTRIBUTION_SIZE 256
 
 typedef enum {
-  AMITK_OPERATION_ADD,
-  AMITK_OPERATION_SUB,
-  AMITK_OPERATION_NUM
-} AmitkOperation;
+  AMITK_OPERATION_UNARY_THRESHOLD,
+  AMITK_OPERATION_UNARY_NUM
+} AmitkOperationUnary;
+
+typedef enum {
+  AMITK_OPERATION_BINARY_ADD,
+  AMITK_OPERATION_BINARY_SUB,
+  AMITK_OPERATION_BINARY_MULTIPLY,
+  AMITK_OPERATION_BINARY_DIVISION,
+  AMITK_OPERATION_BINARY_NUM
+} AmitkOperationBinary;
 
 
 typedef enum {
@@ -112,6 +123,13 @@ typedef enum {
   AMITK_INTERPOLATION_NUM
 } AmitkInterpolation;
 
+typedef enum {
+  AMITK_RENDERING_MPR,
+  AMITK_RENDERING_MIP,
+  AMITK_RENDERING_MINIP,
+  AMITK_RENDERING_NUM
+} AmitkRendering;
+
 typedef enum {
   AMITK_THRESHOLDING_PER_SLICE, 
   AMITK_THRESHOLDING_PER_FRAME, 
@@ -229,6 +247,7 @@ struct _AmitkDataSet
   gchar * subject_name; /* name of the subject */
   gchar * subject_id; /* id of the subject */
   gchar * subject_dob; /* date of birth of the subject */
+  gint series_number; /* series number, used by dicom */
   gchar * dicom_image_type; /* dicom specific image type designator */
   AmitkModality modality;
   AmitkPoint voxel_size;  /* in mm */
@@ -236,11 +255,13 @@ struct _AmitkDataSet
   AmitkScalingType scaling_type; /*  dimensions of internal scaling */
   AmitkRawData * internal_scaling_factor; /* internally (data set) supplied scaling factor */
   AmitkRawData * internal_scaling_intercept; /* internally (data set) supplied scaling intercept */
+  amide_time_t * gate_time; /* array of the trigger times of each gate */
   amide_time_t scan_start;
   amide_time_t * frame_duration; /* array of the duration of each frame */
   AmitkColorTable color_table[AMITK_VIEW_MODE_NUM]; /* the color table to draw this volume in */
   gboolean color_table_independent[AMITK_VIEW_MODE_NUM]; /* whether to use the independent color tables for 2-way or 3-way linked modes*/
   AmitkInterpolation interpolation;
+  AmitkRendering rendering; /* rendering mode - MPR/MIP/MINIP */
   AmitkSubjectOrientation subject_orientation; /* orientation of subject in scanner */
   AmitkSubjectSex subject_sex;
 
@@ -256,6 +277,8 @@ struct _AmitkDataSet
   /* MRI parameters */
   amide_time_t inversion_time; /* in milliseconds */
   amide_time_t echo_time; /* in milliseconds */
+  gdouble diffusion_b_value;
+  AmitkPoint diffusion_direction;
 
   /* Thresholding */
   AmitkThresholding thresholding; /* what sort of thresholding we're using (per slice, global, etc.) */
@@ -281,16 +304,14 @@ struct _AmitkDataSet
   amide_intpoint_t num_view_gates;
 
   GList * slice_cache;
-  gint max_slice_cache_size;
-
 
   /* only used by derived data sets (slices and projections)  */
   /* this is a weak pointer, it should be NULL'ed automatically by gtk on the parent's destruction */
   AmitkDataSet * slice_parent; 
 
   /* misc data items - not saved in .xif file */
-  gdouble gate_time; /* used by dcmtk_interface.cc for sorting by gate */
   gint instance_number; /* used by dcmtk_interface.cc occasionally for sorting */
+  gint gate_num; /* used by dcmtk_interface.cc occasionally for sorting */
 
 };
 
@@ -307,6 +328,7 @@ struct _AmitkDataSetClass
   void (* color_table_independent_changed)(AmitkDataSet * ds,
 					   AmitkViewMode * view_mode);
   void (* interpolation_changed)        (AmitkDataSet * ds);
+  void (* rendering_changed)            (AmitkDataSet * ds);
   void (* subject_orientation_changed)  (AmitkDataSet * ds);
   void (* subject_sex_changed)          (AmitkDataSet * ds);
   void (* conversion_changed)           (AmitkDataSet * ds);
@@ -344,6 +366,7 @@ AmitkDataSet * amitk_data_set_import_raw_file    (const gchar * file_name,
 GList *        amitk_data_set_import_file        (AmitkImportMethod method, 
 						  int submethod,
 						  const gchar * filename,
+						  gchar ** pstudyname,
 						  AmitkPreferences * preferences,
 						  AmitkUpdateFunc update_func,
 						  gpointer update_data);
@@ -404,6 +427,8 @@ void           amitk_data_set_set_color_table_independent(AmitkDataSet * ds,
 							  const gboolean independent);
 void           amitk_data_set_set_interpolation  (AmitkDataSet * ds,
 						  const AmitkInterpolation new_interpolation);
+void           amitk_data_set_set_rendering      (AmitkDataSet * ds,
+						  const AmitkRendering new_rendering);
 void           amitk_data_set_set_subject_orientation    (AmitkDataSet * ds,
 							  const AmitkSubjectOrientation subject_orientation);
 void           amitk_data_set_set_subject_sex    (AmitkDataSet * ds,
@@ -416,6 +441,8 @@ void           amitk_data_set_set_subject_id     (AmitkDataSet * ds,
 						  const gchar * new_id);
 void           amitk_data_set_set_subject_dob    (AmitkDataSet * ds, 
 						  const gchar * new_dob);
+void           amitk_data_set_set_series_number  (AmitkDataSet * ds,
+						  const gint new_series_number);
 void           amitk_data_set_set_dicom_image_type(AmitkDataSet * ds,
 						   const gchar * image_type);
 void           amitk_data_set_set_conversion     (AmitkDataSet * ds,
@@ -434,10 +461,14 @@ void           amitk_data_set_set_displayed_weight_unit  (AmitkDataSet * ds,
 						          AmitkWeightUnit new_weight_unit);
 void           amitk_data_set_set_displayed_cylinder_unit(AmitkDataSet * ds,
 						          AmitkCylinderUnit new_cylinder_unit);
-void           amitk_data_set_set_inversion_time(AmitkDataSet * ds,
-						 amide_time_t new_inversion_time);
-void           amitk_data_set_set_echo_time(AmitkDataSet * ds,
-						 amide_time_t new_echo_tim);
+void           amitk_data_set_set_inversion_time   (AmitkDataSet * ds,
+						    amide_time_t new_inversion_time);
+void           amitk_data_set_set_echo_time        (AmitkDataSet * ds,
+						    amide_time_t new_echo_time);
+void           amitk_data_set_set_diffusion_b_value(AmitkDataSet * ds,
+						    gdouble b_value);
+void           amitk_data_set_set_diffusion_direction(AmitkDataSet * ds,
+						      AmitkPoint direction);
 void           amitk_data_set_set_threshold_window (AmitkDataSet * ds,
 						    const AmitkWindow window,
 						    const AmitkLimit limit,
@@ -446,6 +477,11 @@ void           amitk_data_set_set_view_start_gate(AmitkDataSet * ds,
 						  amide_intpoint_t start_gate);
 void           amitk_data_set_set_view_end_gate  (AmitkDataSet * ds,
 						  amide_intpoint_t end_gate);
+void           amitk_data_set_set_gate_time      (AmitkDataSet * ds,
+						  const guint gate,
+						  amide_time_t time);
+amide_time_t   amitk_data_set_get_gate_time      (const AmitkDataSet * ds,
+						  const guint gate);
 amide_time_t   amitk_data_set_get_start_time     (const AmitkDataSet * ds, 
 						  const guint frame);
 amide_time_t   amitk_data_set_get_end_time       (const AmitkDataSet * ds, 
@@ -461,11 +497,14 @@ void           amitk_data_set_calc_far_corner    (AmitkDataSet * ds);
 
 /* note: calling any of the get_*_max or get_*_min functions will automatically
    call calc_min_max if needed.  The main reason to call this function independently
-   is if you know it'll be needed later, and you'd like to put up a progress 
-   dialog. */
+   is if you know the min/max values will be needed later, and you'd like to put up a 
+   progress dialog. */
 void           amitk_data_set_calc_min_max       (AmitkDataSet * ds,
 						  AmitkUpdateFunc update_func,
 						  gpointer update_data);
+void           amitk_data_set_calc_min_max_if_needed(AmitkDataSet * ds,
+						     AmitkUpdateFunc update_func,
+						     gpointer update_data);
 void           amitk_data_set_slice_calc_min_max (AmitkDataSet * ds,
 						  const amide_intpoint_t frame,
 						  const amide_intpoint_t gate,
@@ -555,10 +594,18 @@ AmitkDataSet * amitk_data_sets_find_with_slice_parent(GList * slices,
 						      const AmitkDataSet * slice_parent);
 GList *        amitk_data_sets_remove_with_slice_parent(GList * slices,
 							const AmitkDataSet * slice_parent);
-AmitkDataSet * amitk_data_sets_math                  (AmitkDataSet * ds1, 
+AmitkDataSet * amitk_data_sets_math_unary            (AmitkDataSet * ds1, 
+						      AmitkOperationUnary operation,
+						      amide_data_t parameter0,
+						      amide_data_t parameter1,
+						      AmitkUpdateFunc update_func,
+						      gpointer update_data);
+AmitkDataSet * amitk_data_sets_math_binary           (AmitkDataSet * ds1, 
 						      AmitkDataSet * ds2, 
-						      AmitkOperation operation,
+						      AmitkOperationBinary operation,
+						      amide_data_t parameter0,
 						      gboolean by_frame,
+						      gboolean maintain_ds1_dim,
 						      AmitkUpdateFunc update_func,
 						      gpointer update_data);
 
@@ -566,16 +613,16 @@ AmitkDataSet * amitk_data_sets_math                  (AmitkDataSet * ds1,
 
 
 /* -------- defines ----------- */
+#define amitk_data_set_get_gate_time_mem(ds) (g_try_new0(amide_time_t,(ds)->raw_data->dim.g))
 #define amitk_data_set_get_frame_duration_mem(ds) (g_try_new0(amide_time_t,(ds)->raw_data->dim.t))
 #define amitk_data_set_get_frame_min_max_mem(ds) (g_try_new0(amide_data_t,(ds)->raw_data->dim.t))
-#define amitk_data_set_dynamic(ds) ((ds)->data_set->dim.t > 1)
-
-
 
 
 const gchar *   amitk_scaling_type_get_name       (const AmitkScalingType scaling_type);
-const gchar *   amitk_operation_get_name          (const AmitkOperation operation);
+const gchar *   amitk_operation_unary_get_name    (const AmitkOperationUnary operation);
+const gchar *   amitk_operation_binary_get_name   (const AmitkOperationBinary operation);
 const gchar *   amitk_interpolation_get_name      (const AmitkInterpolation interpolation);
+const gchar *   amitk_rendering_get_name          (const AmitkRendering rendering);
 const gchar *   amitk_subject_orientation_get_name(const AmitkSubjectOrientation subject_orientation);
 const gchar *   amitk_subject_sex_get_name        (const AmitkSubjectSex subject_sex);
 const gchar *   amitk_thresholding_get_name       (const AmitkThresholding thresholding);
@@ -603,6 +650,7 @@ amide_data_t amitk_cylinder_unit_convert_from     (const amide_data_t cylinder_f
 /* external variables */
 extern AmitkColorTable amitk_modality_default_color_table[];
 extern const gchar * amitk_interpolation_explanations[];
+extern const gchar * amitk_rendering_explanation;
 extern const gchar * amitk_import_menu_names[];
 extern const gchar * amitk_import_menu_explanations[];
 extern const gchar * amitk_export_menu_names[];
