@@ -1,7 +1,7 @@
 /* amitk_object_dialog.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2002-2011 Andy Loening
+ * Copyright (C) 2002-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -75,6 +75,7 @@ struct _AmitkObjectDialog
   GtkWidget * cylinder_unit_menu;
   GtkWidget * creation_date_entry;
   GtkWidget * interpolation_button[AMITK_INTERPOLATION_NUM];
+  GtkWidget * rendering_menu;
   GtkWidget * conversion_button[AMITK_CONVERSION_NUM];
 
   GtkWidget * center_spin[AMITK_AXIS_NUM];
@@ -83,6 +84,7 @@ struct _AmitkObjectDialog
 
   GtkWidget * start_spin;
   GtkWidget * * duration_spins;
+  GtkWidget * * gate_spins;
 
   GtkWidget * isocontour_min_value_entry;
   GtkWidget * isocontour_max_value_entry;
@@ -91,8 +93,12 @@ struct _AmitkObjectDialog
   /* study preferences */
   GtkWidget * roi_width_spin;
   GnomeCanvasItem * roi_item;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  GtkWidget * roi_transparency_spin;
+#else
   GtkWidget * line_style_menu;
   GtkWidget * fill_roi_button;
+#endif
   GtkWidget * layout_button1;
   GtkWidget * layout_button2;
   GtkWidget * panel_layout_button1;
