@@ -1,7 +1,7 @@
 /* amitk_roi_variable_type.c - used to generate the different amitk_roi_*.c files
  *
  * Part of amide - Amide's a Medical Image Data Examiner
- * Copyright (C) 2001-2011 Andy Loening
+ * Copyright (C) 2001-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -278,8 +278,11 @@ static amitk_format_UBYTE_t map_roi_edge(AmitkRawData * map_roi_ds, AmitkVoxel v
 /* intersection data is returned in the form of a volume slice */
 AmitkDataSet * amitk_roi_`'m4_Variable_Type`'_get_intersection_slice(const AmitkRoi * roi,
 								     const AmitkVolume * canvas_slice,
-								     const amide_real_t pixel_dim,
-								     const gboolean fill_map_roi) {
+								     const amide_real_t pixel_dim
+#ifndef AMIDE_LIBGNOMECANVAS_AA
+								     ,const gboolean fill_map_roi
+#endif
+								     ) {
 
 
 
@@ -364,10 +367,17 @@ AmitkDataSet * amitk_roi_`'m4_Variable_Type`'_get_intersection_slice(const Amitk
 	value = AMITK_RAW_DATA_UBYTE_CONTENT(roi->map_data, roi_voxel);
 #if defined(ROI_TYPE_ISOCONTOUR_2D) || defined(ROI_TYPE_FREEHAND_2D)
 	if (value > 0)
-#else
-	if (( value == 1) || ((value > 0) && fill_map_roi))
-#endif
 	  AMITK_RAW_DATA_UBYTE_SET_CONTENT(intersection->raw_data, i_voxel) = 1;
+#else /* ISOCONTOUR_3D or FREEHAND_3D */
+
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+        if (value > 0)
+	  AMITK_RAW_DATA_UBYTE_SET_CONTENT(intersection->raw_data, i_voxel) = value;
+#else
+	if ((value == 1) || ((value > 0) && fill_map_roi))
+	  AMITK_RAW_DATA_UBYTE_SET_CONTENT(intersection->raw_data, i_voxel) = 1;
+#endif
+#endif
       }
 #if FAST_INTERSECTION_SLICE
       POINT_ADD(roi_point, stride[AMITK_AXIS_X], roi_point);
@@ -384,15 +394,18 @@ AmitkDataSet * amitk_roi_`'m4_Variable_Type`'_get_intersection_slice(const Amitk
   }
 
 #if defined(ROI_TYPE_ISOCONTOUR_2D) || defined(ROI_TYPE_FREEHAND_2D)
-  if (!fill_map_roi) {
-    /* mark the edges as such on the 2D isocontour or freehand slices */
-    i_voxel.z = i_voxel.g = i_voxel.t = 0;
-    for (i_voxel.y=0; i_voxel.y<dim.y; i_voxel.y++) 
-      for (i_voxel.x=0; i_voxel.x<dim.x; i_voxel.x++) 
-	if (AMITK_RAW_DATA_UBYTE_CONTENT(intersection->raw_data, i_voxel)) 
-	  AMITK_RAW_DATA_UBYTE_SET_CONTENT(intersection->raw_data, i_voxel) =
-	    map_roi_edge(intersection->raw_data, i_voxel);
-  }
+#ifndef AMIDE_LIBGNOMECANVAS_AA
+  if (!fill_map_roi) 
+#endif
+    {
+      /* mark the edges as such on the 2D isocontour or freehand slices */
+      i_voxel.z = i_voxel.g = i_voxel.t = 0;
+      for (i_voxel.y=0; i_voxel.y<dim.y; i_voxel.y++) 
+	for (i_voxel.x=0; i_voxel.x<dim.x; i_voxel.x++) 
+	  if (AMITK_RAW_DATA_UBYTE_CONTENT(intersection->raw_data, i_voxel)) 
+	    AMITK_RAW_DATA_UBYTE_SET_CONTENT(intersection->raw_data, i_voxel) =
+	      map_roi_edge(intersection->raw_data, i_voxel);
+    }
 #endif
 
   amitk_space_copy_in_place(AMITK_SPACE(intersection), AMITK_SPACE(canvas_slice));
