@@ -1,7 +1,7 @@
 /* amitk_study.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -59,8 +59,12 @@ G_BEGIN_DECLS
 #define AMITK_STUDY_CANVAS_TARGET(stu)            (AMITK_STUDY(stu)->canvas_target)
 
 #define AMITK_STUDY_CANVAS_ROI_WIDTH(stu)         (AMITK_STUDY(stu)->canvas_roi_width)
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+#define AMITK_STUDY_CANVAS_ROI_TRANSPARENCY(stu)  (AMITK_STUDY(stu)->canvas_roi_transparency)
+#else
 #define AMITK_STUDY_CANVAS_LINE_STYLE(stu)        (AMITK_STUDY(stu)->canvas_line_style)
 #define AMITK_STUDY_CANVAS_FILL_ROI(stu)          (AMITK_STUDY(stu)->canvas_fill_roi)
+#endif
 #define AMITK_STUDY_CANVAS_LAYOUT(stu)            (AMITK_STUDY(stu)->canvas_layout)
 #define AMITK_STUDY_CANVAS_MAINTAIN_SIZE(stu)     (AMITK_STUDY(stu)->canvas_maintain_size)
 #define AMITK_STUDY_CANVAS_TARGET_EMPTY_AREA(stu) (AMITK_STUDY(stu)->canvas_target_empty_area)
@@ -100,8 +104,12 @@ struct _AmitkStudy
 
   /* canvas preferences */
   gint canvas_roi_width;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  gdouble canvas_roi_transparency;
+#else
   GdkLineStyle canvas_line_style;
   gboolean canvas_fill_roi;
+#endif
   AmitkLayout canvas_layout;
   gboolean canvas_maintain_size;
   gint canvas_target_empty_area; /* in pixels */
@@ -146,6 +154,8 @@ GType	        amitk_study_get_type	             (void);
 AmitkStudy *    amitk_study_new                     (AmitkPreferences * preferences);
 void            amitk_study_set_filename            (AmitkStudy * study, 
 						     const gchar * new_filename);
+void            amitk_study_suggest_name            (AmitkStudy * study,
+						     const gchar * suggested_name);
 void            amitk_study_set_creation_date       (AmitkStudy * study, 
 						     const gchar * new_date); 
 void            amitk_study_set_view_thickness      (AmitkStudy * study, 
@@ -171,10 +181,15 @@ void            amitk_study_set_canvas_target       (AmitkStudy * study,
 						     const gboolean always_on);
 void            amitk_study_set_canvas_roi_width    (AmitkStudy * study,
 						     gint roi_width);
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+void            amitk_study_set_canvas_roi_transparency(AmitkStudy * study,
+							const gdouble transparency);
+#else
 void            amitk_study_set_canvas_line_style   (AmitkStudy * study,
 						     const GdkLineStyle line_style);
 void            amitk_study_set_canvas_fill_roi     (AmitkStudy * study,
 						     const gboolean fill_roi);
+#endif
 void            amitk_study_set_canvas_layout       (AmitkStudy * study,
 						     const AmitkLayout layout);
 void            amitk_study_set_canvas_maintain_size(AmitkStudy * study,
