@@ -1,7 +1,7 @@
 /* amitk_tree_view.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2002-2011 Andy Loening
+ * Copyright (C) 2002-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -393,7 +393,7 @@ static void tree_view_popup_roi_menu(AmitkTreeView * tree_view, AmitkObject * pa
   menu = gtk_menu_new();
 
   for (i_roi_type=0; i_roi_type<AMITK_ROI_TYPE_NUM; i_roi_type++) {
-    menuitem = gtk_menu_item_new_with_label(amitk_roi_menu_explanation[i_roi_type]);
+    menuitem = gtk_menu_item_new_with_label(_(amitk_roi_menu_explanation[i_roi_type]));
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
     g_object_set_data(G_OBJECT(menuitem), "roi_type", GINT_TO_POINTER(i_roi_type)); 
     g_object_set_data(G_OBJECT(menuitem), "parent", parent_object);
@@ -469,6 +469,16 @@ static gboolean tree_view_button_press_event (GtkWidget      *widget,
   return return_value;
 }
 
+static path_compare(GtkTreePath * path1, GtkTreePath * path2) {
+
+  if ((path1 == NULL) && (path2 == NULL))
+    return 0;
+  else if ((path1 == NULL) || (path2 == NULL))
+    return 1;
+  else
+    return gtk_tree_path_compare(path1, path2);
+}
+
 static gboolean tree_view_button_release_event (GtkWidget      *widget,
 						GdkEventButton *event) {
   GtkTreePath * path=NULL;
@@ -496,7 +506,7 @@ static gboolean tree_view_button_release_event (GtkWidget      *widget,
        also check that we're doing a button release on the object we started
        the button press with */
     if (column != gtk_tree_view_get_expander_column(GTK_TREE_VIEW(tree_view)) &&
-	gtk_tree_path_compare(path, tree_view->current_path)==0) {
+	path_compare(path, tree_view->current_path)==0) {
       
       GtkTreeModel * model;
       GtkTreeIter iter;
@@ -594,7 +604,13 @@ static gboolean tree_view_button_release_event (GtkWidget      *widget,
 	  tree_view_popup_roi_menu(tree_view, object, event->button, event->time);
 	break;
 
-
+      case AMITK_TREE_VIEW_MODE_SINGLE_SELECTION:
+	switch (event->button) {
+	case 1: /* left button */
+	  g_signal_emit(G_OBJECT(tree_view), tree_view_signals[ACTIVATE_OBJECT],0,object);
+	  break;
+	}
+	break;
 
       case AMITK_TREE_VIEW_MODE_MULTIPLE_SELECTION:
 	switch (event->button) {
@@ -1080,7 +1096,7 @@ static void tree_view_drag_data_received (GtkWidget        *widget,
       if ((import_filename = g_filename_from_uri(uris[uris_index], NULL, NULL)) == NULL)
 	g_warning("Could not generate filename for URI: %s", uris[uris_index]);
       else {
-	dropped_ds = amitk_data_set_import_file(AMITK_IMPORT_METHOD_GUESS, 0, import_filename,
+	dropped_ds = amitk_data_set_import_file(AMITK_IMPORT_METHOD_GUESS, 0, import_filename, NULL,
 						tree_view->preferences, amitk_progress_dialog_update, tree_view->progress_dialog);
 	g_free(import_filename);
 	if (dropped_ds != NULL) {
@@ -1423,6 +1439,8 @@ GtkWidget* amitk_tree_view_new (AmitkTreeViewMode tree_mode,
     /* by default, only first select column is shown */
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), tree_view->select_column[AMITK_VIEW_MODE_SINGLE]);
     break;
+  case AMITK_TREE_VIEW_MODE_SINGLE_SELECTION:
+    break;
   case AMITK_TREE_VIEW_MODE_MULTIPLE_SELECTION:
     gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), column);
     break;
@@ -1451,6 +1469,7 @@ GtkWidget* amitk_tree_view_new (AmitkTreeViewMode tree_mode,
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
   switch (tree_view->mode) {
   case AMITK_TREE_VIEW_MODE_MAIN:
+  case AMITK_TREE_VIEW_MODE_SINGLE_SELECTION:
     gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
     break;
   case AMITK_TREE_VIEW_MODE_MULTIPLE_SELECTION:
@@ -1493,6 +1512,12 @@ void amitk_tree_view_expand_object(AmitkTreeView * tree_view, AmitkObject * obje
   return;
 }
 
+/* this function can return NULL */
+AmitkObject * amitk_tree_view_get_active_object(AmitkTreeView * tree_view) {
+
+  g_return_val_if_fail(AMITK_IS_TREE_VIEW(tree_view), NULL);
+  return tree_view->active_object;
+}
 
 void amitk_tree_view_set_active_object(AmitkTreeView * tree_view, AmitkObject * object) {
 
@@ -1500,7 +1525,8 @@ void amitk_tree_view_set_active_object(AmitkTreeView * tree_view, AmitkObject *
   GtkTreeIter iter;
 
   g_return_if_fail(AMITK_IS_TREE_VIEW(tree_view));
-  g_return_if_fail(tree_view->mode == AMITK_TREE_VIEW_MODE_MAIN);
+  g_return_if_fail((tree_view->mode == AMITK_TREE_VIEW_MODE_MAIN) ||
+		   (tree_view->mode == AMITK_TREE_VIEW_MODE_SINGLE_SELECTION));
 
   if (tree_view->active_object != NULL) {
     amitk_object_unref(tree_view->active_object);
