@@ -1,7 +1,7 @@
 /* amitk_tree_view.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2002-2011 Andy Loening
+ * Copyright (C) 2002-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -41,10 +41,10 @@ G_BEGIN_DECLS
 
 typedef enum {
   AMITK_TREE_VIEW_MODE_MAIN,
+  AMITK_TREE_VIEW_MODE_SINGLE_SELECTION,
   AMITK_TREE_VIEW_MODE_MULTIPLE_SELECTION,
   AMITK_TREE_VIEW_MODE_NUM
 } AmitkTreeViewMode;
-  //  AMITK_TREE_MODE_SINGLE_SELECTION,
 
 typedef struct _AmitkTreeView             AmitkTreeView;
 typedef struct _AmitkTreeViewClass        AmitkTreeViewClass;
@@ -100,9 +100,10 @@ GtkWidget*      amitk_tree_view_new               (AmitkTreeViewMode tree_mode,
 						   AmitkPreferences * preferences,
 						   GtkWidget * progress_dialog);
 void            amitk_tree_view_set_study         (AmitkTreeView * tree_view,
-					      AmitkStudy * study);
+					           AmitkStudy * study);
 void            amitk_tree_view_expand_object     (AmitkTreeView * tree_view,
 						   AmitkObject * object);
+AmitkObject *   amitk_tree_view_get_active_object (AmitkTreeView * tree_view);
 void            amitk_tree_view_set_active_object (AmitkTreeView * tree_view,
 						   AmitkObject * object);
 GList *         amitk_tree_view_get_multiple_selection_objects(AmitkTreeView * tree_view);
