@@ -1,7 +1,7 @@
 /* image.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -155,7 +155,11 @@ static void image_free_rgb_data(guchar * pixels, gpointer data) {
 GdkPixbuf * image_slice_intersection(const AmitkRoi * roi,
 				     const AmitkVolume * canvas_slice,
 				     const amide_real_t pixel_size,
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+				     const gdouble transparency,
+#else
 				     const gboolean fill_roi,
+#endif
 				     rgba_t color,
 				     AmitkPoint * return_offset,
 				     AmitkPoint * return_corner) {
@@ -165,9 +169,18 @@ GdkPixbuf * image_slice_intersection(const AmitkRoi * roi,
   AmitkVoxel i;
   guchar * rgba_data;
   AmitkVoxel dim;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  guchar transparency_byte;
+
+  transparency_byte = transparency * 0xFF;
+#endif
 
   
-  intersection = amitk_roi_get_intersection_slice(roi, canvas_slice, pixel_size, fill_roi);
+  intersection = amitk_roi_get_intersection_slice(roi, canvas_slice, pixel_size 
+#ifndef AMIDE_LIBGNOMECANVAS_AA
+						  , fill_roi
+#endif
+						  );
   if (intersection == NULL) return NULL;
 
   dim = AMITK_DATA_SET_DIM(intersection);
@@ -189,7 +202,18 @@ GdkPixbuf * image_slice_intersection(const AmitkRoi * roi,
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+0] = color.r;
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+1] = color.g;
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+2] = color.b;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+3] = color.a;
+#else
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+3] = 0xFF;
+#endif
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+      }	else if (AMITK_RAW_DATA_UBYTE_CONTENT(intersection->raw_data, i) == 2) {
+	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+0] = color.r;
+	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+1] = color.g;
+	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+2] = color.b;
+	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+3] = transparency_byte;
+#endif
       }	else {
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+0] = 0x00;
 	rgba_data[(dim.y-i.y-1)*dim.x*4 + i.x*4+1] = 0x00;
