@@ -1,7 +1,7 @@
 /* image.h
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -40,7 +40,11 @@
 GdkPixbuf * image_slice_intersection(const AmitkRoi * roi,
 				     const AmitkVolume * canvas_slice,
 				     const amide_real_t pixel_size,
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+				     const gdouble transparency,
+#else
 				     const gboolean fill_roi,
+#endif
 				     rgba_t color,
 				     AmitkPoint * return_offset,
 				     AmitkPoint * return_corner);
