@@ -1,7 +1,7 @@
 /* tb_math.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2006-2011 Andy Loening
+ * Copyright (C) 2006-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -30,20 +30,22 @@
 #include "tb_math.h"
 
 
+#define SPIN_BUTTON_X_SIZE 100
 #define LABEL_WIDTH 375
 
 
 static gchar * data_set_error_page_text = 
-N_("There is only one data set in this study.  There needs "
-   "to be at least two data sets to perform mathematical operations");
+N_("There are no data sets in this study to perform "
+   "mathematical operations on.");
 
 static gchar * start_page_text = 
 N_("Welcome to the data set math wizard, used for "
-   "performing mathematical operations between medical "
+   "performing mathematical operations on and between medical "
    "image data sets.\n"
    "\n"
-   "Note - you will get more pleasing results if the data "
-   "sets in question are set to trilinear interpolation mode.");
+   "Note - If performing an operation between two data sets, you "
+   "will likely get more pleasing results if the data sets in "
+   "question are set to trilinear interpolation mode.");
 
 
 typedef enum {
@@ -60,8 +62,9 @@ typedef enum {
 
 typedef enum {
   INTRO_PAGE, 
-  DATA_SETS_PAGE, 
   OPERATION_PAGE,
+  DATA_SETS_PAGE, 
+  PARAMETERS_PAGE,
   CONCLUSION_PAGE, 
   NUM_PAGES
 } which_page_t;
@@ -71,26 +74,42 @@ typedef struct tb_math_t {
   GtkWidget * dialog;
   GtkWidget * page[NUM_PAGES];
   GtkWidget * progress_dialog;
+  GtkWidget * scrolled_ds1;
   GtkWidget * list_ds1;
+  GtkWidget * scrolled_ds2;
   GtkWidget * list_ds2;
   GtkWidget * list_operation;
+  GtkWidget * parameter0_label;
+  GtkWidget * parameter0_spin;
+  GtkWidget * parameter1_label;
+  GtkWidget * parameter1_spin;
+  GtkWidget * by_frames_check_button;
+  GtkWidget * maintain_ds1_dim_check_button;
 
   AmitkStudy * study;
+  gint ds_count;
   AmitkDataSet * ds1;
   AmitkDataSet * ds2;
-  AmitkOperation operation;
+  gint operation; 
+  amide_data_t parameter0;
+  amide_data_t parameter1;
   gboolean by_frames;
+  gboolean maintain_ds1_dim;
 
   guint reference_count;
 } tb_math_t;
 
 
 
-static void data_sets_update_model(tb_math_t * math);
 static void operation_update_model(tb_math_t * math);
-static void data_set_selection_changed_cb(GtkTreeSelection * selection, gpointer data);
+static void data_sets_update_model(tb_math_t * math);
+static void parameters_update_page(tb_math_t * math);
 static void operation_selection_changed_cb(GtkTreeSelection * selection, gpointer data);
+static void data_set_selection_changed_cb(GtkTreeSelection * selection, gpointer data);
+static void parameter0_spinner_cb(GtkSpinButton * spin_button, gpointer data);
+static void parameter1_spinner_cb(GtkSpinButton * spin_button, gpointer data);
 static void by_frames_cb(GtkWidget * widget, gpointer data);
+static void maintain_ds1_dim_cb(GtkWidget * widget, gpointer data);
 
 static tb_math_t * tb_math_free(tb_math_t * math);
 static tb_math_t * tb_math_init(void);
@@ -100,10 +119,49 @@ static void apply_cb(GtkAssistant * assistant, gpointer data);
 static void close_cb(GtkAssistant * assistant, gpointer data);
 
 
-static GtkWidget * create_data_sets_page(tb_math_t * tb_math);
 static GtkWidget * create_operation_page(tb_math_t * tb_math);
+static GtkWidget * create_data_sets_page(tb_math_t * tb_math);
+static GtkWidget * create_parameters_page(tb_math_t * tb_math);
 
 
+
+static void operation_update_model(tb_math_t * tb_math) {
+
+  GtkTreeIter iter;
+  GtkTreeModel * model;
+  gint i_operation;
+  GtkTreeSelection *selection;
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tb_math->list_operation));
+  model = gtk_tree_view_get_model(GTK_TREE_VIEW(tb_math->list_operation));
+
+  gtk_list_store_clear(GTK_LIST_STORE(model));  /* make sure the list is clear */
+
+  /* put in the unary operations */
+  for (i_operation=0; i_operation < AMITK_OPERATION_UNARY_NUM; i_operation++) {
+    gtk_list_store_append (GTK_LIST_STORE(model), &iter);  /* Acquire an iterator */
+    gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+		       COLUMN_OPERATION_NAME, amitk_operation_unary_get_name(i_operation),
+		       COLUMN_OPERATION_NUMBER, i_operation, -1);
+    if (i_operation == tb_math->operation)
+      gtk_tree_selection_select_iter (selection, &iter);
+  }
+
+  /* put in the binary operations if we have more then one data set */
+  if (tb_math->ds_count > 1) {
+    for (i_operation=AMITK_OPERATION_UNARY_NUM; i_operation < AMITK_OPERATION_UNARY_NUM+AMITK_OPERATION_BINARY_NUM; i_operation++) {
+      gtk_list_store_append (GTK_LIST_STORE(model), &iter);  /* Acquire an iterator */
+      gtk_list_store_set(GTK_LIST_STORE(model), &iter,
+			 COLUMN_OPERATION_NAME, amitk_operation_binary_get_name(i_operation-AMITK_OPERATION_UNARY_NUM),
+			 COLUMN_OPERATION_NUMBER, i_operation, -1);
+      if (i_operation == tb_math->operation)
+	gtk_tree_selection_select_iter (selection, &iter);
+    }
+  }
+
+  return;
+}
+
 static void data_sets_update_model(tb_math_t * tb_math) {
 
   GtkTreeIter iter;
@@ -139,19 +197,25 @@ static void data_sets_update_model(tb_math_t * tb_math) {
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(tb_math->list_ds2));
   gtk_list_store_clear(GTK_LIST_STORE(model));  /* make sure the list is clear */
 
-  temp_data_sets = data_sets;
-  count = 0;
-  while (temp_data_sets != NULL) {
-    gtk_list_store_append (GTK_LIST_STORE(model), &iter);  /* Acquire an iterator */
-    gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-			COLUMN_DATA_SET_NAME, AMITK_OBJECT_NAME(temp_data_sets->data),
-			COLUMN_DATA_SET_POINTER, temp_data_sets->data, -1);
-    if (((tb_math->ds2 == NULL) && (tb_math->ds1 != temp_data_sets->data))  ||
-	(tb_math->ds2 == temp_data_sets->data))
-    if (count == 1)
-      gtk_tree_selection_select_iter (selection, &iter);
-    count++;
-    temp_data_sets = temp_data_sets->next;
+  if (tb_math->operation < AMITK_OPERATION_UNARY_NUM) {
+    gtk_widget_hide(tb_math->scrolled_ds2);
+  } else { /* binary operation */
+    gtk_widget_show(tb_math->scrolled_ds2);
+
+    temp_data_sets = data_sets;
+    count = 0;
+    while (temp_data_sets != NULL) {
+      gtk_list_store_append (GTK_LIST_STORE(model), &iter);  /* Acquire an iterator */
+      gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+			  COLUMN_DATA_SET_NAME, AMITK_OBJECT_NAME(temp_data_sets->data),
+			  COLUMN_DATA_SET_POINTER, temp_data_sets->data, -1);
+      if (((tb_math->ds2 == NULL) && (tb_math->ds1 != temp_data_sets->data))  ||
+	  (tb_math->ds2 == temp_data_sets->data))
+	if (count == 1)
+	  gtk_tree_selection_select_iter (selection, &iter);
+      count++;
+      temp_data_sets = temp_data_sets->next;
+    }
   }
 
   if (data_sets != NULL)
@@ -160,32 +224,52 @@ static void data_sets_update_model(tb_math_t * tb_math) {
   return;
 }
 
-static void operation_update_model(tb_math_t * tb_math) {
+static void parameters_update_page(tb_math_t * tb_math) {
 
+  if (tb_math->operation == AMITK_OPERATION_UNARY_THRESHOLD) {
+    gtk_label_set_text(GTK_LABEL(tb_math->parameter0_label), _("Set to 0 below:"));
+    gtk_widget_show(tb_math->parameter0_label);
+    gtk_widget_show(tb_math->parameter0_spin);
+    gtk_label_set_text(GTK_LABEL(tb_math->parameter1_label), _("Set to 1 above:"));
+    gtk_widget_show(tb_math->parameter1_label);
+    gtk_widget_show(tb_math->parameter1_spin);
+    gtk_widget_hide(tb_math->by_frames_check_button);
+    gtk_widget_hide(tb_math->maintain_ds1_dim_check_button);
+  } else if (tb_math->operation == (AMITK_OPERATION_UNARY_NUM+AMITK_OPERATION_BINARY_DIVISION)) {
+    gtk_label_set_text(GTK_LABEL(tb_math->parameter0_label), _("Set to 0 if Divisor below:"));
+    gtk_widget_show(tb_math->parameter0_label);
+    gtk_widget_show(tb_math->parameter0_spin);
+    gtk_widget_hide(tb_math->parameter1_label);
+    gtk_widget_hide(tb_math->parameter1_spin);
+    gtk_widget_show(tb_math->by_frames_check_button);
+    gtk_widget_show(tb_math->maintain_ds1_dim_check_button);
+  } else{ /* other binary operations */  
+    gtk_widget_hide(tb_math->parameter0_label);
+    gtk_widget_hide(tb_math->parameter0_spin);
+    gtk_widget_hide(tb_math->parameter1_label);
+    gtk_widget_hide(tb_math->parameter1_spin);
+    gtk_widget_show(tb_math->by_frames_check_button);
+    gtk_widget_show(tb_math->maintain_ds1_dim_check_button);
+  }
+ 
+  return;
+}
+
+static void operation_selection_changed_cb(GtkTreeSelection * selection, gpointer data) {
+
+  tb_math_t * tb_math = data;
+  gint operation;
   GtkTreeIter iter;
   GtkTreeModel * model;
-  AmitkOperation i_operation;
-  GtkTreeSelection *selection;
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tb_math->list_operation));
-  model = gtk_tree_view_get_model(GTK_TREE_VIEW(tb_math->list_operation));
-
-  gtk_list_store_clear(GTK_LIST_STORE(model));  /* make sure the list is clear */
-
-  /* put in the possible operations */
-  for (i_operation=0; i_operation < AMITK_OPERATION_NUM; i_operation++) {
-    gtk_list_store_append (GTK_LIST_STORE(model), &iter);  /* Acquire an iterator */
-    gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-		       COLUMN_OPERATION_NAME, amitk_operation_get_name(i_operation),
-		       COLUMN_OPERATION_NUMBER, i_operation, -1);
-    if (i_operation == tb_math->operation)
-      gtk_tree_selection_select_iter (selection, &iter);
+  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+    gtk_tree_model_get(model, &iter, COLUMN_OPERATION_NUMBER, &operation, -1);
+    tb_math->operation = operation;
   }
 
   return;
 }
 
-
 static void data_set_selection_changed_cb(GtkTreeSelection * selection, gpointer data) {
 
   tb_math_t * tb_math = data;
@@ -216,10 +300,13 @@ static void data_set_selection_changed_cb(GtkTreeSelection * selection, gpointer
       break;
     }
   }
-  
-  can_continue = ((tb_math->ds1 != NULL) &&
-		  (tb_math->ds2 != NULL) &&
-		  (tb_math->ds1 != tb_math->ds2));
+
+  if (tb_math->operation < AMITK_OPERATION_UNARY_NUM)
+    can_continue = (tb_math->ds1 != NULL);
+  else /* binary operation */
+    can_continue = ((tb_math->ds1 != NULL) &&
+		    (tb_math->ds2 != NULL) &&
+		    (tb_math->ds1 != tb_math->ds2));
 
   gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog),
 				  tb_math->page[DATA_SETS_PAGE], 
@@ -228,24 +315,15 @@ static void data_set_selection_changed_cb(GtkTreeSelection * selection, gpointer
   return;
 }
 
-static void operation_selection_changed_cb(GtkTreeSelection * selection, gpointer data) {
-
+static void parameter0_spinner_cb(GtkSpinButton * spin_button, gpointer data) {
   tb_math_t * tb_math = data;
-  AmitkOperation operation;
-  GtkTreeIter iter;
-  GtkTreeModel * model;
-
-  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-
-    gtk_tree_model_get(model, &iter, COLUMN_OPERATION_NUMBER, &operation, -1);
-
-    g_return_if_fail(operation >= 0);
-    g_return_if_fail(operation < AMITK_OPERATION_NUM);
-    
-    tb_math->operation = operation;
-
-  }
+  tb_math->parameter0 = gtk_spin_button_get_value(spin_button);
+  return;
+}
 
+static void parameter1_spinner_cb(GtkSpinButton * spin_button, gpointer data) {
+  tb_math_t * tb_math = data;
+  tb_math->parameter1 = gtk_spin_button_get_value(spin_button);
   return;
 }
 
@@ -255,6 +333,12 @@ static void by_frames_cb(GtkWidget * widget, gpointer data) {
   return;
 }
 
+static void maintain_ds1_dim_cb(GtkWidget * widget, gpointer data) {
+  tb_math_t * tb_math = data;
+  tb_math->maintain_ds1_dim = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+  return;
+}
+
 
 static void prepare_page_cb(GtkAssistant * wizard, GtkWidget * page, gpointer data) {
  
@@ -265,13 +349,16 @@ static void prepare_page_cb(GtkAssistant * wizard, GtkWidget * page, gpointer da
   which_page = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(page), "which_page"));
 
   switch(which_page) {
+  case OPERATION_PAGE:
+    operation_update_model(tb_math); 
+    break;
   case DATA_SETS_PAGE:
     data_sets_update_model(tb_math);
     //    gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog), page, 
     //				    (tb_math->ds1 != NULL) && (tb_math->ds2 != NULL) && (tb_math->ds1 != tb_math->ds2));
     break;
-  case OPERATION_PAGE:
-    operation_update_model(tb_math); 
+  case PARAMETERS_PAGE:
+    parameters_update_page(tb_math);
     break;
   case CONCLUSION_PAGE:
     temp_string = g_strdup_printf(_("A new data set will be created with the math operation, press Finish to calculate this data set, or Cancel to quit."));
@@ -293,15 +380,28 @@ static void apply_cb(GtkAssistant * assistant, gpointer data) {
 
   /* sanity check */
   g_return_if_fail(tb_math->ds1 != NULL);
-  g_return_if_fail(tb_math->ds2 != NULL);
 
   /* apply the math */
-  output_ds = amitk_data_sets_math(tb_math->ds1, 
-				   tb_math->ds2, 
-				   tb_math->operation,
-				   tb_math->by_frames,
-				   amitk_progress_dialog_update,
-				   tb_math->progress_dialog);
+
+  if (tb_math->operation < AMITK_OPERATION_UNARY_NUM) {
+    output_ds = amitk_data_sets_math_unary(tb_math->ds1, 
+					   tb_math->operation,
+					   tb_math->parameter0,
+					   tb_math->parameter1,
+					   amitk_progress_dialog_update,
+					   tb_math->progress_dialog);
+  } else {
+    g_return_if_fail(tb_math->ds2 != NULL); /* sanity check */
+    output_ds = amitk_data_sets_math_binary(tb_math->ds1, 
+					    tb_math->ds2, 
+					    tb_math->operation-AMITK_OPERATION_UNARY_NUM,
+					    tb_math->parameter0,
+					    tb_math->by_frames,
+					    tb_math->maintain_ds1_dim,
+					    amitk_progress_dialog_update,
+					    tb_math->progress_dialog);
+  }
+
   if (output_ds != NULL) {
     amitk_object_add_child(AMITK_OBJECT(tb_math->study), AMITK_OBJECT(output_ds));
     amitk_object_unref(output_ds);
@@ -390,15 +490,48 @@ static tb_math_t * tb_math_init(void) {
   tb_math->reference_count = 1;
   tb_math->dialog = NULL;
   tb_math->study = NULL;
+  tb_math->ds_count=0;
   tb_math->ds1 = NULL;
   tb_math->ds2 = NULL;
-  tb_math->operation = AMITK_OPERATION_ADD;
+  tb_math->operation = AMITK_OPERATION_BINARY_ADD;
+  tb_math->parameter0 = 0.0;
+  tb_math->parameter1 = 0.0;
   tb_math->by_frames = FALSE;
+  tb_math->maintain_ds1_dim = FALSE;
 
   return tb_math;
 }
 
 
+static GtkWidget * create_operation_page(tb_math_t * tb_math) {
+
+  GtkWidget * table;
+  GtkListStore * store;
+  GtkCellRenderer *renderer;
+  GtkTreeViewColumn *column;
+  GtkTreeSelection *selection;
+
+  table = gtk_table_new(3,2,FALSE);
+    
+  store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+  tb_math->list_operation = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+  g_object_unref(store);
+
+  renderer = gtk_cell_renderer_text_new ();
+  column = gtk_tree_view_column_new_with_attributes(_("Math Operation"), renderer,
+						    "text", COLUMN_OPERATION_NAME, NULL);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (tb_math->list_operation), column);
+
+  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tb_math->list_operation));
+  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+  g_signal_connect(G_OBJECT(selection), "changed",
+		   G_CALLBACK(operation_selection_changed_cb), tb_math);
+  gtk_table_attach(GTK_TABLE(table),tb_math->list_operation, 0,1,0,1,
+		   GTK_FILL|GTK_EXPAND, GTK_FILL | GTK_EXPAND,X_PADDING, Y_PADDING);
+
+  return table;
+}
+
 static GtkWidget * create_data_sets_page(tb_math_t * tb_math) {
 
   GtkWidget * table;
@@ -426,7 +559,11 @@ static GtkWidget * create_data_sets_page(tb_math_t * tb_math) {
   g_signal_connect(G_OBJECT(selection), "changed",
 		   G_CALLBACK(data_set_selection_changed_cb), tb_math);
 
-  gtk_table_attach(GTK_TABLE(table),tb_math->list_ds1, 0,1,0,1,
+  tb_math->scrolled_ds1 = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(tb_math->scrolled_ds1), 
+				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_container_add(GTK_CONTAINER(tb_math->scrolled_ds1), tb_math->list_ds1);
+  gtk_table_attach(GTK_TABLE(table),tb_math->scrolled_ds1, 0,1,0,1,
 		   GTK_FILL|GTK_EXPAND, GTK_FILL | GTK_EXPAND,X_PADDING, Y_PADDING);
 
 
@@ -449,57 +586,84 @@ static GtkWidget * create_data_sets_page(tb_math_t * tb_math) {
   g_signal_connect(G_OBJECT(selection), "changed",
 		   G_CALLBACK(data_set_selection_changed_cb), tb_math);
 
-  gtk_table_attach(GTK_TABLE(table),tb_math->list_ds2, 2,3,0,1,
+  tb_math->scrolled_ds2 = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(tb_math->scrolled_ds2), 
+				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_container_add(GTK_CONTAINER(tb_math->scrolled_ds2), tb_math->list_ds2);
+  gtk_table_attach(GTK_TABLE(table),tb_math->scrolled_ds2, 2,3,0,1,
 		   GTK_FILL|GTK_EXPAND, GTK_FILL | GTK_EXPAND,X_PADDING, Y_PADDING);
 
   return table;
 }
 
-static GtkWidget * create_operation_page(tb_math_t * tb_math) {
+
+static GtkWidget * create_parameters_page(tb_math_t * tb_math) {
 
   GtkWidget * table;
-  GtkListStore * store;
-  GtkCellRenderer *renderer;
-  GtkTreeViewColumn *column;
-  GtkTreeSelection *selection;
-  GtkWidget * check_button;
+  gint table_row = 0;
 
   table = gtk_table_new(3,2,FALSE);
+
+
+  tb_math->parameter0_label = gtk_label_new(NULL); /* label set in parameter_page_update function */
+  gtk_table_attach(GTK_TABLE(table), tb_math->parameter0_label, 0,1, table_row,table_row+1,
+		   FALSE, FALSE, X_PADDING, Y_PADDING);
     
-  store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
-  tb_math->list_operation = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
-  g_object_unref(store);
+  tb_math->parameter0_spin = gtk_spin_button_new_with_range(-G_MAXDOUBLE, G_MAXDOUBLE, 1.0);
+  gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(tb_math->parameter0_spin), FALSE);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(tb_math->parameter0_spin), tb_math->parameter0);
+  gtk_widget_set_size_request(tb_math->parameter0_spin, SPIN_BUTTON_X_SIZE, -1);
+  g_signal_connect(G_OBJECT(tb_math->parameter0_spin), "value_changed",  
+		   G_CALLBACK(parameter0_spinner_cb), tb_math);
+  g_signal_connect(G_OBJECT(tb_math->parameter0_spin), "output",
+		   G_CALLBACK(amitk_spin_button_scientific_output), NULL);
+  gtk_table_attach(GTK_TABLE(table), tb_math->parameter0_spin, 1,2, table_row,table_row+1,
+		   FALSE,FALSE, X_PADDING, Y_PADDING);
+  table_row++;
 
-  renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes(_("Math Operation"), renderer,
-						    "text", COLUMN_OPERATION_NAME, NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (tb_math->list_operation), column);
+  tb_math->parameter1_label = gtk_label_new(NULL); /* label set in parameter_page_update function */
+  gtk_table_attach(GTK_TABLE(table), tb_math->parameter1_label, 0,1, table_row,table_row+1,
+		   FALSE, FALSE, X_PADDING, Y_PADDING);
+    
+  tb_math->parameter1_spin = gtk_spin_button_new_with_range(-G_MAXDOUBLE, G_MAXDOUBLE, 1.0);
+  gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(tb_math->parameter1_spin), FALSE);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(tb_math->parameter1_spin), tb_math->parameter1);
+  gtk_widget_set_size_request(tb_math->parameter1_spin, SPIN_BUTTON_X_SIZE, -1);
+  g_signal_connect(G_OBJECT(tb_math->parameter1_spin), "value_changed",  
+		   G_CALLBACK(parameter1_spinner_cb), tb_math);
+  g_signal_connect(G_OBJECT(tb_math->parameter1_spin), "output",
+		   G_CALLBACK(amitk_spin_button_scientific_output), NULL);
+  gtk_table_attach(GTK_TABLE(table), tb_math->parameter1_spin, 1,2, table_row,table_row+1,
+		   FALSE,FALSE, X_PADDING, Y_PADDING);
+  table_row++;
 
-  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tb_math->list_operation));
-  gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-  g_signal_connect(G_OBJECT(selection), "changed",
-		   G_CALLBACK(operation_selection_changed_cb), tb_math);
-  gtk_table_attach(GTK_TABLE(table),tb_math->list_operation, 0,1,0,1,
-		   GTK_FILL|GTK_EXPAND, GTK_FILL | GTK_EXPAND,X_PADDING, Y_PADDING);
-
-  check_button = gtk_check_button_new_with_label ("Do operation frame-by-frame (default is by time)");
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), tb_math->by_frames);
-  g_signal_connect(G_OBJECT(check_button), "toggled", G_CALLBACK(by_frames_cb),tb_math);
-  gtk_table_attach(GTK_TABLE(table), check_button,0,1,1,2,
+  tb_math->by_frames_check_button = 
+    gtk_check_button_new_with_label (_("Do binary operation frame-by-frame (default is by time)"));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tb_math->by_frames_check_button), tb_math->by_frames);
+  g_signal_connect(G_OBJECT(tb_math->by_frames_check_button), "toggled", G_CALLBACK(by_frames_cb),tb_math);
+  gtk_table_attach(GTK_TABLE(table), tb_math->by_frames_check_button,0,2,table_row,table_row+1,
 		   GTK_FILL, 0, X_PADDING, Y_PADDING);
-  gtk_widget_show(check_button);
+  table_row++;
+
+  tb_math->maintain_ds1_dim_check_button = 
+    gtk_check_button_new_with_label(_("Maintain data set 1 dimensions (default is superset of both data sets)"));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tb_math->maintain_ds1_dim_check_button), tb_math->maintain_ds1_dim);
+  g_signal_connect(G_OBJECT(tb_math->maintain_ds1_dim_check_button), "toggled", G_CALLBACK(maintain_ds1_dim_cb),tb_math);
+  gtk_table_attach(GTK_TABLE(table), tb_math->maintain_ds1_dim_check_button,0,2,table_row,table_row+1,
+		   GTK_FILL, 0, X_PADDING, Y_PADDING);
+  table_row++;
 
   return table;
 }
 
 
 
+
 /* function that sets up an image math dialog */
 void tb_math(AmitkStudy * study, GtkWindow * parent) {
 
   tb_math_t * tb_math;
   GdkPixbuf * logo;
-  guint count;
   GList * data_sets;
   gint i;
   
@@ -522,10 +686,10 @@ void tb_math(AmitkStudy * study, GtkWindow * parent) {
   /* --------------- initial page ------------------ */
   /* figure out how many data sets there are */
   data_sets = amitk_object_get_children_of_type(AMITK_OBJECT(tb_math->study), AMITK_OBJECT_TYPE_DATA_SET, TRUE);
-  count = amitk_data_sets_count(data_sets, TRUE);
+  tb_math->ds_count = amitk_data_sets_count(data_sets, TRUE);
   if (data_sets != NULL) data_sets = amitk_objects_unref(data_sets);
 
-  tb_math->page[INTRO_PAGE]= gtk_label_new((count >= 2) ? start_page_text : data_set_error_page_text);
+  tb_math->page[INTRO_PAGE]= gtk_label_new((tb_math->ds_count >= 1) ? _(start_page_text) : _(data_set_error_page_text));
   gtk_widget_set_size_request(tb_math->page[INTRO_PAGE],LABEL_WIDTH, -1);
   gtk_label_set_line_wrap(GTK_LABEL(tb_math->page[INTRO_PAGE]), TRUE);
   gtk_assistant_append_page(GTK_ASSISTANT(tb_math->dialog), tb_math->page[INTRO_PAGE]);
@@ -533,14 +697,7 @@ void tb_math(AmitkStudy * study, GtkWindow * parent) {
 			       _("Data Set Math Wizard"));
   gtk_assistant_set_page_type(GTK_ASSISTANT(tb_math->dialog), tb_math->page[INTRO_PAGE],
 			      GTK_ASSISTANT_PAGE_INTRO);
-  gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog), tb_math->page[INTRO_PAGE], count >= 2);
-
-
-  /*------------------ pick your data set page ------------------ */
-  tb_math->page[DATA_SETS_PAGE] = create_data_sets_page(tb_math);
-  gtk_assistant_append_page(GTK_ASSISTANT(tb_math->dialog), tb_math->page[DATA_SETS_PAGE]);
-  gtk_assistant_set_page_title(GTK_ASSISTANT(tb_math->dialog), tb_math->page[DATA_SETS_PAGE], 
-			       _("Data Set Selection"));
+  gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog), tb_math->page[INTRO_PAGE], tb_math->ds_count >= 1);
 
 
   /*------------------ pick your operation page ------------------ */
@@ -550,6 +707,18 @@ void tb_math(AmitkStudy * study, GtkWindow * parent) {
 			       _("Operation Selection"));
   gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog),tb_math->page[OPERATION_PAGE], TRUE); /* we always have one selected */
 
+  /*------------------ pick your data set page ------------------ */
+  tb_math->page[DATA_SETS_PAGE] = create_data_sets_page(tb_math);
+  gtk_assistant_append_page(GTK_ASSISTANT(tb_math->dialog), tb_math->page[DATA_SETS_PAGE]);
+  gtk_assistant_set_page_title(GTK_ASSISTANT(tb_math->dialog), tb_math->page[DATA_SETS_PAGE], 
+			       _("Data Set Selection"));
+
+  /*------------------ additional parameters ------------------ */
+  tb_math->page[PARAMETERS_PAGE] = create_parameters_page(tb_math);
+  gtk_assistant_append_page(GTK_ASSISTANT(tb_math->dialog), tb_math->page[PARAMETERS_PAGE]);
+  gtk_assistant_set_page_title(GTK_ASSISTANT(tb_math->dialog), tb_math->page[PARAMETERS_PAGE], 
+			       _("Parameter Selection"));
+  gtk_assistant_set_page_complete(GTK_ASSISTANT(tb_math->dialog),tb_math->page[PARAMETERS_PAGE], TRUE);
 
   /* ----------------  conclusion page ---------------------------------- */
   tb_math->page[CONCLUSION_PAGE] = gtk_label_new("");
