@@ -1,7 +1,7 @@
 /* tb_profile.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2003-2011 Andy Loening
+ * Copyright (C) 2003-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -747,7 +747,9 @@ static void display_gaussian_fit(tb_profile_t * tb_profile) {
 			  gnome_canvas_line_get_type(),
 			  "points", points,
 			  "fill_color", "white",
+#ifndef AMIDE_LIBGNOMECANVAS_AA
 			  "line_style", GDK_LINE_ON_OFF_DASH,
+#endif
 			  "width_units", 1.0,
 			  NULL);
   gnome_canvas_points_unref(points);
@@ -762,7 +764,9 @@ static void display_gaussian_fit(tb_profile_t * tb_profile) {
 			  gnome_canvas_line_get_type(),
 			  "points", points,
 			  "fill_color", "white",
+#ifndef AMIDE_LIBGNOMECANVAS_AA
 			  "line_style", GDK_LINE_ON_OFF_DASH,
+#endif
 			  "width_units", 1.0,
 			  NULL);
   gnome_canvas_points_unref(points);
@@ -789,9 +793,14 @@ static void display_gaussian_fit(tb_profile_t * tb_profile) {
       points->coords[2*j+1] = CANVAS_HEIGHT-EDGE_SPACING-result->scale_y*(value-result->min_y);
     }
 
-    /* figure ou the color we'll use */
+    /* figure out the color we'll use */
     x = div(i, NUM_COLOR_ROTATIONS);
-    color = tb_profile->results->len < 2 ? 0xFFFFFFFF : color_rotation[x.rem];
+    if (tb_profile->results->len < 2) {
+      color = 0xFFFFFFFF;
+    } else {
+      color = color_rotation[x.rem];
+    }
+
 
     /* make sure it's destroyed */
     if (result->fit_item != NULL)
@@ -803,7 +812,9 @@ static void display_gaussian_fit(tb_profile_t * tb_profile) {
 			    gnome_canvas_line_get_type(),
 			    "points", points,
 			    "fill_color_rgba", color,
+#ifndef AMIDE_LIBGNOMECANVAS_AA
 			    "line_style", GDK_LINE_ON_OFF_DASH,
+#endif
 			    "width_units", 1.0,
 			    NULL);
     gnome_canvas_points_unref(points);
@@ -935,7 +946,7 @@ static gboolean update_while_idle(gpointer data) {
 			    "anchor", GTK_ANCHOR_SOUTH_WEST, "text", label,
 			    "x", (gdouble) EDGE_SPACING+5.0,
 			    "y", (gdouble) CANVAS_HEIGHT-EDGE_SPACING,
-			    "fill_color", "white", 
+			    "fill_color", "white",
 			    "font_desc", amitk_fixed_font_desc, NULL);
   }
   g_free(label);
@@ -950,7 +961,7 @@ static gboolean update_while_idle(gpointer data) {
 			    "anchor", GTK_ANCHOR_SOUTH_EAST, "text", label,
 			    "x", (gdouble) CANVAS_WIDTH-EDGE_SPACING,
 			    "y", (gdouble) CANVAS_HEIGHT-EDGE_SPACING,
-			    "fill_color", "white", 
+			    "fill_color", "white",
 			    "font_desc", amitk_fixed_font_desc, NULL);
   }
   g_free(label);
@@ -1283,13 +1294,13 @@ void tb_profile(AmitkStudy * study, AmitkPreferences * preferences, GtkWindow *
 			gnome_canvas_rect_get_type(),
 			"x1",0.0, "y1", 0.0, 
 			"x2", (gdouble) CANVAS_WIDTH, "y2", (gdouble) CANVAS_HEIGHT,
-			"fill_color_rgba", 0x00000000,
+			"fill_color_rgba", 0x000000FF,
 			NULL);
 
   
   /* the fit results */
 #ifdef AMIDE_LIBGSL_SUPPORT
-  check_button = gtk_check_button_new_with_label ("calculate gaussian fit");
+  check_button = gtk_check_button_new_with_label (_("calculate gaussian fit"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), tb_profile->calc_gaussian_fit);
   g_signal_connect(G_OBJECT(check_button), "toggled", G_CALLBACK(calc_gaussian_fit_cb), tb_profile);
   gtk_table_attach(GTK_TABLE(table), check_button,0,3,
@@ -1297,7 +1308,7 @@ void tb_profile(AmitkStudy * study, AmitkPreferences * preferences, GtkWindow *
   gtk_widget_show(check_button);
   table_row++;
 
-  check_button = gtk_check_button_new_with_label ("fix x location (c)");
+  check_button = gtk_check_button_new_with_label (_("fix x location (c)"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), tb_profile->fix_x);
   g_signal_connect(G_OBJECT(check_button), "toggled", G_CALLBACK(fix_x_cb), tb_profile);
   gtk_table_attach(GTK_TABLE(table), check_button,0,3,
@@ -1305,7 +1316,7 @@ void tb_profile(AmitkStudy * study, AmitkPreferences * preferences, GtkWindow *
   gtk_widget_show(check_button);
   table_row++;
 
-  check_button = gtk_check_button_new_with_label ("fix dc value to zero (b)");
+  check_button = gtk_check_button_new_with_label (_("fix dc value to zero (b)"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), tb_profile->fix_dc_zero);
   g_signal_connect(G_OBJECT(check_button), "toggled", G_CALLBACK(fix_dc_zero_cb), tb_profile);
   gtk_table_attach(GTK_TABLE(table), check_button,0,3,
