@@ -1,7 +1,7 @@
 /* ui_series.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2011 Andy Loening
+ * Copyright (C) 2000-2012 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -87,8 +87,12 @@ typedef struct ui_series_t {
   gboolean in_generation;
   gboolean quit_generation;
   gint roi_width;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  gdouble roi_transparency;
+#else
   GdkLineStyle line_style;
   gboolean fill_roi;
+#endif
   gint pixbuf_width;
   gint pixbuf_height;
 
@@ -407,6 +411,7 @@ static void menus_toolbar_create(ui_series_t * ui_series) {
 
   /* create an action group with all the menu actions */
   action_group = gtk_action_group_new ("MenuActions");
+  gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
   gtk_action_group_add_actions(action_group, normal_items, G_N_ELEMENTS(normal_items),ui_series);
   gtk_action_group_add_actions(action_group, ui_common_help_menu_items, G_N_ELEMENTS(ui_common_help_menu_items),ui_series);
 
@@ -584,8 +589,12 @@ static ui_series_t * ui_series_init(GtkWindow * window, GtkWidget * window_vbox)
   ui_series->in_generation=FALSE;
   ui_series->quit_generation=FALSE;
   ui_series->roi_width = 1.0;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  ui_series->roi_transparency = 0.5;
+#else
   ui_series->line_style = 0;
   ui_series->fill_roi = TRUE;
+#endif
   ui_series->pixbuf_width = 0;
   ui_series->pixbuf_height = 0;
 
@@ -866,8 +875,13 @@ static gboolean update_immediate(gpointer data) {
 					x+UI_SERIES_L_MARGIN, y+UI_SERIES_TOP_MARGIN,
 					outline_color, 
 					ui_series->roi_width,
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+					ui_series->roi_transparency
+#else
 					ui_series->line_style,
-					ui_series->fill_roi);
+					ui_series->fill_roi
+#endif
+					);
 	if (item != NULL)
 	  ui_series->items[i-start_i] = g_list_append(ui_series->items[i-start_i], item);
       }
@@ -963,7 +977,7 @@ void ui_series_create(AmitkStudy * study,
   g_return_if_fail(AMITK_IS_STUDY(study));
 
   title = g_strdup_printf(_("Series: %s (%s - %s)"), AMITK_OBJECT_NAME(study),
-			  amitk_view_get_name(view), series_names[series_type]);
+			  amitk_view_get_name(view), _(series_names[series_type]));
   window = GTK_WINDOW(gtk_window_new(GTK_WINDOW_TOPLEVEL));
   gtk_window_set_title(window, title);
   g_free(title);
@@ -978,8 +992,12 @@ void ui_series_create(AmitkStudy * study,
   ui_series = ui_series_init(window, window_vbox);
   ui_series->preferences = g_object_ref(preferences);
   ui_series->series_type = series_type;
+#ifdef AMIDE_LIBGNOMECANVAS_AA
+  ui_series->roi_transparency = AMITK_STUDY_CANVAS_ROI_TRANSPARENCY(study);
+#else
   ui_series->line_style = AMITK_STUDY_CANVAS_LINE_STYLE(study);
   ui_series->fill_roi = AMITK_STUDY_CANVAS_FILL_ROI(study);
+#endif
   ui_series->roi_width = AMITK_STUDY_CANVAS_ROI_WIDTH(study);
 
   ui_series->objects = amitk_objects_ref(selected_objects);
@@ -1237,6 +1255,8 @@ void ui_series_create(AmitkStudy * study,
 		       G_CALLBACK(data_set_invalidate_slice_cache), ui_series);
       g_signal_connect(G_OBJECT(temp_objects->data), "interpolation_changed", 
 		       G_CALLBACK(changed_cb), ui_series);
+      g_signal_connect(G_OBJECT(temp_objects->data), "rendering_changed", 
+		       G_CALLBACK(changed_cb), ui_series);
     } 
     g_signal_connect(G_OBJECT(temp_objects->data), "space_changed", 
 		     G_CALLBACK(changed_cb), ui_series);
@@ -1314,10 +1334,6 @@ GtkWidget * ui_series_init_dialog_create(AmitkStudy * study, GtkWindow * parent)
   GtkWidget * hseparator;
   GtkWidget * scrolled;
   GtkWidget * tree_view;
-#if (GTK_MINOR_VERSION >= 12)
-#else
-  GtkTooltips * tips;
-#endif
   series_type_t i_series_type;
   AmitkView i_view;
   series_type_t series_type;
@@ -1343,10 +1359,6 @@ GtkWidget * ui_series_init_dialog_create(AmitkStudy * study, GtkWindow * parent)
   table = gtk_table_new(7,3,FALSE);
   table_row=0;
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
-#if (GTK_MINOR_VERSION >= 12)
-#else
-  tips = gtk_tooltips_new();
-#endif
 
   /* what series type do we want */
   label = gtk_label_new(_("Series Type:"));
@@ -1356,19 +1368,13 @@ GtkWidget * ui_series_init_dialog_create(AmitkStudy * study, GtkWindow * parent)
   for (i_series_type = 0; i_series_type < NUM_SERIES_TYPES; i_series_type++) {
     if (i_series_type == 0) 
       radio_button[i_series_type] = 
-	gtk_radio_button_new_with_label(NULL, series_names[i_series_type]);
+	gtk_radio_button_new_with_label(NULL, _(series_names[i_series_type]));
     else
       radio_button[i_series_type] = 
 	gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_button[0]), 
-						    series_names[i_series_type]);
-#if (GTK_MINOR_VERSION >= 12)
+						    _(series_names[i_series_type]));
     gtk_widget_set_tooltip_text(radio_button[i_series_type], 
-				series_explanations[i_series_type]);
-#else
-    gtk_tooltips_set_tip(tips, radio_button[i_series_type], 
-			 series_explanations[i_series_type],
-			 series_explanations[i_series_type]);
-#endif
+				_(series_explanations[i_series_type]));
     gtk_table_attach(GTK_TABLE(table), radio_button[i_series_type], 1, 2, 
 		     table_row, table_row+1, GTK_FILL, 0, X_PADDING, Y_PADDING);
     g_object_set_data(G_OBJECT(radio_button[i_series_type]), "series_type", 
